---
name: Bug report
about: Create a report to help us improve

---

# Description

A clear and concise description of what the bug is.

# To Reproduce

Steps to reproduce the behavior:

1. Run command `...`
2. Input `...`
3. See error: ...

# Expected behavior

A clear and concise description of what you expected to happen.

# Screenshots

If applicable, add screenshots to help explain your problem.

# Environment

- OS: [e.g. Windows 10]
- Python: [e.g. 3.7.0]
- ecr: [e.g. 0.0.2]
- pip packages (optional):

# Additional context

Add any other context about the problem here.
